@@ -12,3 +12,6 @@ PHU="-e  1 30308952520/4489860107041 3178376 971037955"
 OBLX="-e 1 150/197 49 1"
 PROX="-e 1 150/53 1 49"
 WGS84="-e 1 124/18523 1 0"
+T321="-e 1 2 3 5"
+ORIG="-e 1 3801/10000 3600 201"
+BILL="-e 1 10101/10000 9900 201"
